@@ -22,12 +22,14 @@ void DialogsTests::testSettingsDialog()
     settingsDlg.setSingleCategory(qtSettings.category());
 
     // add another empty category
-    auto testCategory = OptionCategory();
-    testCategory.setDisplayName(QStringLiteral("Test category"));
-    testCategory.setIcon(QIcon::fromTheme(QStringLiteral("preferences")));
+    auto *const testCategory = new OptionCategory();
+    testCategory->setDisplayName(QStringLiteral("Test category"));
+    testCategory->setIcon(QIcon::fromTheme(QStringLiteral("preferences")));
+    settingsDlg.showCategory(nullptr);  // ensure no current category is shown anymore
     settingsDlg.setSingleCategory(nullptr);
-    settingsDlg.categoryModel()->setCategories(QList<OptionCategory *>({&testCategory, qtSettings.category()}));
-    settingsDlg.showCategory(qtSettings.category());
+    auto *const qtCategory = qtSettings.category();
+    settingsDlg.categoryModel()->setCategories(QList<OptionCategory *>({testCategory, qtCategory}));
+    settingsDlg.showCategory(qtCategory);
     settingsDlg.show();
 }
 
